Package: sg3-utils
Version: 1.21-2
Severity: normal
Tags: patch

Hi,

Attached is the diff for my sg3-utils 1.21-2.1 NMU.

-- 
Luk Claes - http://people.debian.org/~luk - GPG key 1024D/9B7C328D
Fingerprint:   D5AF 25FB 316B 53BB 08E7   F999 E544 DE07 9B7C 328D
diff -u sg3-utils-1.21/debian/changelog sg3-utils-1.21/debian/changelog
--- sg3-utils-1.21/debian/changelog
+++ sg3-utils-1.21/debian/changelog
@@ -1,3 +1,10 @@
+sg3-utils (1.21-2.1) unstable; urgency=medium
+
+  * Non-maintainer upload.
+  * Fix FTBFS due to old syscall usage (Closes: #395512).
+
+ -- Luk Claes <[EMAIL PROTECTED]>  Sun,  5 Nov 2006 17:23:29 +0100
+
 sg3-utils (1.21-2) unstable; urgency=low
 
   * Added Depends on libsgutils1 to libsgutils1-dev (closes: #387798)
only in patch2:
unchanged:
--- sg3-utils-1.21.orig/llseek.c
+++ sg3-utils-1.21/llseek.c
@@ -26,30 +26,27 @@
 
 #ifdef __linux__
 
-#ifdef HAVE_LLSEEK
-#include <syscall.h>
-
-#else   /* HAVE_LLSEEK */
-
 #if defined(__alpha__) || defined(__ia64__)  || defined(__s390x__)
 
 #define my_llseek lseek
 
 #else
-#include <linux/unistd.h>       /* for __NR__llseek */
+#include <sys/syscall.h>       /* for SYS__llseek */
 
 static int _llseek (unsigned int, unsigned long,
                    unsigned long, llse_loff_t *, unsigned int);
 
-#ifdef __NR__llseek
+#ifdef SYS__llseek
 
-static _syscall5(int,_llseek,unsigned int,fd,unsigned long,offset_high,
-                 unsigned long, offset_low,llse_loff_t *,result,
-                 unsigned int, origin)
+static int _llseek(unsigned int fd,unsigned long offset_high,
+                 unsigned long offset_low,llse_loff_t *result,
+                 unsigned int origin) {
+       return syscall(SYS__llseek, fd, offset_high, offset_low, result, 
origin);
+}
 
 #else
 
 /* no __NR__llseek on compilation machine - might give it explicitly */
 static int _llseek (unsigned int fd, unsigned long oh,
                     unsigned long ol, llse_loff_t *result,
                     unsigned int origin) {
@@ -73,8 +70,6 @@
 
 #endif /* __alpha__ */
 
-#endif  /* HAVE_LLSEEK */
-
 llse_loff_t llse_llseek (unsigned int fd, llse_loff_t offset,
                          unsigned int origin)
 {
@@ -26,30 +26,27 @@
 #else
 
-/* no __NR__llseek on compilation machine - might give it explicitly */
+/* no SYS__llseek on compilation machine - might give it explicitly */
 static int _llseek (unsigned int fd, unsigned long oh,
                     unsigned long ol, llse_loff_t *result,

Reply via email to